@@ -17,10 +17,7 @@
    Boston, MA 02111-1307, USA.  */
 
 #include <stdio.h>
-
-extern int __path_search (char *tmpl, size_t tmpl_len, const char *dir, const char *pfx,
-	       int try_tmpdir);
-extern int __gen_tempname (char *tmpl, int openit);
+#include "../misc/internals/tempname.h"
 
 /* Generate a unique filename in P_tmpdir.  If S is NULL return NULL.
    This makes this function thread safe.  */
@@ -31,7 +28,7 @@ char * tmpnam_r (char *s)
 
     if (__path_search (s, L_tmpnam, NULL, NULL, 0))
 	return NULL;
-    if (__gen_tempname (s, 0))
+    if (__gen_tempname (s, __GT_NOCREATE))
 	return NULL;
 
     return s;
